==> canon-runtime-java-0.0.6-sources.jar: org/symphonyoss/s2/canon/runtime/EntityArrayFactory.java <==
/*
 *
 *
 * Copyright 2017 Symphony Communication Services, LLC.
 *
 * Licensed to The Symphony Software Foundation (SSF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The SSF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

package org.symphonyoss.s2.canon.runtime;

import org.symphonyoss.s2.common.dom.DomSerializer;
import org.symphonyoss.s2.common.dom.json.IImmutableJsonDomNode;
import org.symphonyoss.s2.common.dom.json.IJsonDomNodeProvider;
import org.symphonyoss.s2.common.dom.json.ImmutableJsonArray;

public abstract class EntityArrayFactory<M extends IEntityArray, F extends IModel>
implements IEntityArrayFactory<M,F>
{
  protected static final DomSerializer SERIALIZER = DomSerializer.newBuilder().withCanonicalMode(true).build();
  
  public abstract static class Builder implements IJsonDomNodeProvider, IBaseEntity
  {
    public abstract ImmutableJsonArray getJsonArray();
    
    @Override
    public IImmutableJsonDomNode getJsonDomNode()
    {
      return getJsonArray();
    }

    @Override
    public String serialize()
    {
      return SERIALIZER.serialize(getJsonArray());
    }
  }
}

==> canon-runtime-java-0.0.24-sources.jar: org/symphonyoss/s2/canon/runtime/EntityArrayFactory.java <==
/*
 *
 *
 * Copyright 2017 Symphony Communication Services, LLC.
 *
 * Licensed to The Symphony Software Foundation (SSF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The SSF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

package org.symphonyoss.s2.canon.runtime;

import org.symphonyoss.s2.common.dom.json.IJsonDomNodeProvider;
import org.symphonyoss.s2.common.immutable.ImmutableByteArray;

public abstract class EntityArrayFactory<M extends IEntityArray>
implements IEntityArrayFactory<M>
{
  //protected static final DomSerializer SERIALIZER = DomSerializer.newBuilder().withCanonicalMode(true).build();
  
  public abstract static class Builder implements IJsonDomNodeProvider, IBaseEntity
  {
    @Override
    public ImmutableByteArray serialize()
    {
      //return SERIALIZER.serialize(getJsonDomNode());
      return getJsonDomNode().serialize();
    }

    @Override
    public String toString()
    {
      return getJsonDomNode().toString();
    }
  }
}
